thorn.utils.json — Thorn 1.3.0 documentation

# thorn.utils.json

- thorn.utils.json

## thorn.utils.json

Json serialization utilities.

class `thorn.utils.json.` `JsonEncoder`(skipkeys=False, ensure_ascii=True, check_circular=True, allow_nan=True, sort_keys=False, indent=None, separators=None, encoding='utf-8', default=None)
  `default`(o, dates=(<type 'datetime.datetime'>, <type 'datetime.date'>), times=(<type 'datetime.time'>, ), textual=(<class 'decimal.Decimal'>, <class 'uuid.UUID'>, <class 'django.utils.functional.Promise'>), isinstance=<built-in function isinstance>, datetime=<type 'datetime.datetime'>, text_type=<type 'unicode'>)

`thorn.utils.json.` `dumps`(obj, encode=<function dumps>, cls=<class 'thorn.utils.json.JsonEncoder'>)